=========
Threading
=========


Installation
============

The default threading runtime has no dependencies other than Pykka itself and
the Python standard library.


API
===

.. autoclass:: pykka.ThreadingFuture
    :members:

.. autoclass:: pykka.ThreadingActor
    :members:
